#!/usr/bin/env python
# -*- coding: utf8 -*-
# Author: Tony <stayblank@gmail.com>
# Create: 2019/5/26 23:02
from datetime import datetime
import unittest

from time_kong import TimeKong


class TestTimeKong(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_datetime2timestamp(self):
        d = datetime(year=2019, month=5, day=26, hour=22, minute=42, second=26, microsecond=330232)
        ts = TimeKong.datetime2timestamp(d)
        self.assertEqual(1558881746.330232, ts)


if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf8 -*-
# Author: Tony <stayblank@gmail.com>
# Create: 2019/5/26 22:19
__all__ = ["TimeGen"]


class TimeGen(object):
    ONE_MILLISECOND = 0.001
    ONE_SECOND = 1
    ONE_MINUTE_SECONDS = 60 * ONE_SECOND
    ONE_HOUR_SECONDS = 60 * ONE_MINUTE_SECONDS
    ONE_DAY_SECONDS = 24 * ONE_HOUR_SECONDS
    ONE_MONTH_SECONDS = 30 * ONE_DAY_SECONDS
    ONE_YEAR_SECONDS = 365 * ONE_MONTH_SECONDS

    @classmethod
    def n_milliseconds(cls, n):
        return n * cls.ONE_MILLISECOND

    @classmethod
    def n_seconds(cls, n):
        return n * cls.ONE_SECOND

    @classmethod
    def n_minutes(cls, n):
        return n * cls.ONE_MINUTE_SECONDS

    @classmethod
    def n_hours(cls, n):
        return n * cls.ONE_HOUR_SECONDS

    @classmethod
    def n_days(cls, n):
        return n * cls.ONE_DAY_SECONDS

    @classmethod
    def n_months(cls, n):
        return n * cls.ONE_MONTH_SECONDS

    @classmethod
    def n_years(cls, n):
        return n * cls.ONE_YEAR_SECONDS



#!/usr/bin/env python
# -*- coding: utf8 -*-
# Author: Tony <stayblank@gmail.com>
# Create: 2019/5/26 21:57
from .time_kong import TimeKong
from .time_gen import TimeGen

__all__ = ["TimeKong", "TimeGen"]



#!/usr/bin/env python
# -*- coding: utf8 -*-
# Author: Tony <stayblank@gmail.com>
# Create: 2019/5/26 22:09
from setuptools import setup, find_packages
import os

with open(os.path.join(os.path.dirname(__file__), "README.md")) as f:
    long_description = f.read()

setup(
    name="time-kong",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/PurpleSun/time_kong",
    version="0.0.1",
    keywords=("time", "transform", "convert"),
    description="A useful time transform util, transforms between string, timestamp and datetime format",
    license="MIT License",
    install_requires=[],
    author="fanwei.zeng",
    author_email="stayblank@gmail.com",
    packages=find_packages(),
    package_data={},
    include_package_data=True,
    platforms="any"
)



#!/usr/bin/env python
# -*- coding: utf8 -*-
# Author: Tony <stayblank@gmail.com>
# Create: 2019/5/26 21:57
import time
from datetime import datetime

__all__ = ["TimeKong"]


class TimeKong(object):
    FORMATTER = "%Y-%m-%d %H:%M:%S"

    @staticmethod
    def timestamp2datetime(timestamp, tz=None):
        return datetime.fromtimestamp(timestamp, tz=tz)

    @classmethod
    def timestamp2string(cls, timestamp, formatter=None):
        d = cls.timestamp2datetime(timestamp)
        return cls.datetime2string(d, formatter)

    @staticmethod
    def datetime2timestamp(d):
        a = time.mktime(d.timetuple())
        b = d.microsecond / 1e6
        return a + b

    @classmethod
    def datetime2string(cls, d, formatter=None):
        formatter = formatter or cls.FORMATTER
        return d.strftime(formatter)

    @classmethod
    def string2timestamp(cls, s, formatter=None):
        d = cls.string2datetime(s, formatter)
        return cls.datetime2timestamp(d)

    @classmethod
    def string2datetime(cls, s, formatter=None):
        formatter = formatter or cls.FORMATTER
        return datetime.strptime(s, formatter)

    @classmethod
    def floor_to_millisecond(cls, timestamp):
        return round(timestamp, 3)

    @classmethod
    def floor_to_second(cls, timestamp):
        return round(timestamp, 1)

    @classmethod
    def floor_to_minute(cls, timestamp):
        d = cls.timestamp2datetime(timestamp)
        floor_d = datetime(year=d.year, month=d.month, day=d.day, hour=d.hour, minute=d.minute)
        return cls.datetime2timestamp(floor_d)

    @classmethod
    def floor_to_hour(cls, timestamp):
        d = cls.timestamp2datetime(timestamp)
        floor_d = datetime(year=d.year, month=d.month, day=d.day, hour=d.hour)
        return cls.datetime2timestamp(floor_d)

    @classmethod
    def floor_to_day(cls, timestamp):
        d = cls.timestamp2datetime(timestamp)
        floor_d = datetime(year=d.year, month=d.month, day=d.day)
        return cls.datetime2timestamp(floor_d)

    @classmethod
    def floor_to_month(cls, timestamp):
        d = cls.timestamp2datetime(timestamp)
        floor_d = datetime(year=d.year, month=d.month, day=1)
        return cls.datetime2timestamp(floor_d)

    @classmethod
    def floor_to_year(cls, timestamp):
        d = cls.timestamp2datetime(timestamp)
        floor_d = datetime(year=d.year, month=1, day=1)
        return cls.datetime2timestamp(floor_d)
